Opinions

## Opinions for Eastern Appellate District

#### Step 1. Select or Change Court

Court:

#### Step 2. Search Opinions ...

Need Help?

#### ... OR View By Date

Year of Opinion:
Show all Opinions for Year Hide all Opinions
Click on a date below to view opinions.

EDOrder-05-06-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99696: Overview/Summary State of Missouri, Respondent, vs. Jeremiah F. McMillon, Appellant. Author: Clifford H. Ahrens, J. Vote: AFFIRMED. Roy L. Richter, P.J., and Glenn A. Norton, J., concur.
ED100289: Overview/Summary Jennifer Philips, Amber Philips, Mariah Philips, and Ian Philips Next Friend Jennifer Philips, Appellants, vs. Citimortgage, Inc., Respondent. Author: Robert M. Clayton III, C.J. Vote: AFFIRMED IN PART AND REVERSED AND REMANDED IN PART. Clifford H. Ahrens, J., and Mary R. Russell, Sp.J., concur.
ED100215: Overview/Summary In Re the Marriage of: Tracey Marie Steinberg, Appellant, vs. Michael Frank Steinberg, Respondent. Author: Lawrence E. Mooney, P.J. Vote: REVERSED AND REMANDED WITH INSTRUCTIONS. Robert G. Dowd, Jr., J., and Sherri B. Sullivan, J., concur.
ED100114: Overview/Summary Steve Hibbs, Appellant, vs. Brian Berger, et al., Respondents. Author: Roy L. Richter, P.J. Vote: AFFIRMED. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED100075: Overview/Summary Aaron Davis, Appellant, v. J.P. Collier, Inc. and Division of Employment Security, Respondents. Author: Clifford H. Ahrens, J. Vote: AFFIRMED. Roy L. Richter, P.J., and Glenn A. Norton, J., concur.
ED100035: Overview/Summary State of Missouri, Respondent, v. Jeffrey A. Chandler, Appellant. Author: Clifford H. Ahrens, J. Vote: AFFIRMED. Roy L. Richter, P.J., and Glenn A. Norton, J., concur.
ED100012: Overview/Summary Valerie Naeger, Plaintiff/Appellant, v. Farmers Insurance Company, Inc., Defendant/Respondent. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Robert G. Dowd, Jr., J., concurs. Lawrence E. Mooney, P.J., dissents in separate opinion.
EDOrder-04-29-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99778: Overview/Summary State of Missouri, Respondent, vs. Michael Sutherland, Appellant. Author: Angela T. Quigless, Judge Vote: AFFIRMED. Mary K. Hoff, Presiding Judge, concurs and Kurt S. Odenwald, Judge, dissents in separate opinion.
ED99545: Overview/Summary Orpheus D. Warren, Movant/Appellant, vs. State of Missouri, Respondent. Author: Lisa S. Van Amburg, P.J. Vote: AFFIRMED UNDER RULE 84.16(b) AND CORRECTED TO REMOVE THE PRIOR AND PERSISTENT OFFENDER CLASSIFICATIONS FROM THE JUDGMENT AND SENTENCE FORM. Patricia L. Cohen, Judge, and Philip M. Hess, Judge, concur.
ED99468: Overview/Summary State of Missouri, Respondent, vs. Raymon Denzmore, Appellant. Author: Patricia L. Cohen, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J., and Philip M. Hess, J., concur.
ED99186: Overview/Summary David A. McArthur, Appellant, vs. State of Missouri, Respondent. Author: Patricia L. Cohen, Judge Vote: AFFIRMED AND REMANDED FOR CORRECTION OF JUDGMENT NUNC PRO TUNC. Lisa S. Van Amburg, P.J., and Philip M. Hess, J., concur.
ED99044: Overview/Summary State of Missouri, Respondent/Cross-Appellant, vs. Elvis Smith, Appellant. Author: Patricia L. Cohen, J. Vote: AFFIRMED AND REMANDED FOR CORRECTION OF JUDGMENT NUNC PRO TUNC. Lisa S. Van Amburg, P.J., and Philip M. Hess, J., concur.
ED100421: Overview/Summary Spirit & Truth Church, et al., Plaintiffs/Respondents, vs. Mark Barnaby, et al., Defendants/Appellants. Author: Robert G. Dowd, Jr., J. Vote: REVERSED. Lawrence E. Mooney, P.J. and Sherri B. Sullivan, J., concur.
ED100309: Overview/Summary Charlotte Benton, Plaintiff/Appellant, vs. Cracker Barrel Old Country Stores, Inc., Defendant/Respondent. Author: Philip M. Hess, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J. and Patricia L. Cohen, J., concur.
ED100202: Overview/Summary In the Matter of the Care and Treatment of William Doyle, Appellant. Author: Gary M. Gaertner, Jr., J. Vote: AFFIRMED. Robert M. Clayton III, C.J., and Gary Dial, S.J., concur.
ED100036: Overview/Summary State of Missouri, Plaintiff/Respondent, vs. Keith Mason, Defendant/Appellant. Author: Philip M. Hess, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J., and Patricia L. Cohen, J., concur.
ED100009: Overview/Summary State of Missouri, Plaintiff/Respondent, v. Gary L. Francis, Jr., Defendant/Appellant. Author: Sherri B. Sullivan, J. Vote: REVERSED AND REMANDED. Lawrence E. Mooney, P.J. and Robert G. Dowd, Jr., J., concur.
ED99603: Overview/Summary Charles K. Moore, Appellant, vs. State of Missouri, Respondent. Author: Robert G. Dowd, Jr., J. Vote: REVERSED AND REMANDED. Lawrence E. Mooney, P.J. and Sherri B. Sullivan, J., concur.
ED99060: Overview/Summary Pulaski Bank, Respondent, vs. Nantucket Partners, L.C., a Missouri Limited Liability Company, and Julian Hess, Defendants, and Keith Barket, Appellant. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concur.
ED100569: Overview/Summary Captiva Lake Investments, LLC, a Missouri Limited Liability Company, and Cypress Condominium at the Lake of the Ozarks Association, Plaintiffs/Appellants, v. Ameristructure, Inc., a Missouri Corporation, and Stephen J. Sacco, Defendants/Respondents. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Robert G. Dowd, Jr., J., concur.
ED100197: Overview/Summary David Darr, Appellant, vs. Roberts Marketing Group, LLC and Division of Employment Security, Respondents. Author: Karl A.W. DeMarce, S.J. Vote: REVERSED AND REMANDED. Robert M. Clayton III, C.J., and Gary M. Gaertner, Jr., J., concur.
EDOrder-04-15-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99938: Overview/Summary Robert H. Gurley, Movant/Appellant, vs. State of Missouri, Respondent. Author: Lisa S. Van Amburg, J. Vote: AFFIRMED. Patricia L. Cohen, Judge, and Philip M. Hess, Judge, concur.
ED99819: Overview/Summary State of Missouri, Respondent, vs. Stephen Caines, Appellant. Author: Robert G. Dowd, Jr., J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Sherri B. Sullivan, J., concur.
ED99804: Overview/Summary Investors Alliance, LLC, Plaintiff/Respondent, vs. Inez Bordeaux, Defendant/Appellant. Author: Philip M. Hess, J. Vote: REVERSED AND REMANDED. Lisa S. Van Amburg, P.J., and Patricia L. Cohen, J., concur.
ED99782: Overview/Summary Mary L. Lehmann, et al., Respondents, vs. Bank of America, N.A., d/b/a U.S. Trust, Appellant. Author: Kurt S. Odenwald, J. Vote: AFFIRMED IN PART AND REVERSED AND REMANDED IN PART. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concur.
ED99773: Overview/Summary Meagan Garland, Petitioner/Appellant, vs. Director, Family Support Division, Missouri Department of Social Services and Jeffrey Ruhl, Respondents. Author: Lisa S. Van Amburg, P.J. Vote: REVERSED AND REMANDED. Patricia L. Cohen, Judge, concurs. Gary M. Gaertner, Jr., Judge, dissents in separate opinion.
ED99701: Overview/Summary Marcus McCoy, Movant/Appellant, vs. State of Missouri, Respondent. Author: Philip M. Hess, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J., and Patricia L. Cohen, J., concur.
ED99089: Overview/Summary State of Missouri, Plaintiff/Respondent, vs. Kevin Murray, Defendant/Appellant. Author: Lisa S. Van Amburg, J. Vote: AFFIRMED. Patricia L. Cohen, Judge, and Philip M. Hess, Judge, concur.
ED100402: Overview/Summary Desiree Ridgell, Plaintiff/Appellant, vs. Mark McDermott and Karen McDermott, Defendants/Respondents. Author: Angela T. Quigless, J. Vote: REVERSED. Mary K. Hoff, P.J., and Kurt S. Odenwald, J., Concurs.
ED100117: Overview/Summary Aaron H. Johnson, Appellant, vs. State of Missouri, Respondent. Author: Roy L. Richter, P.J. Vote: DISMISSED IN PART; AFFIRMED IN PART. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED100027: Overview/Summary Rolanda D. Pearson, Appellant, vs. Department of Employment Security, Respondent. Author: Lawrence E. Mooney, P.J. Vote: APPEAL DISMISSED AND CAUSE REMANDED WITH INSTRUCTIONS. Robert G. Dowd., Jr., J., and Sherri B. Sullivan, J., concur.
ED100001: Overview/Summary Xiaoyan Gu, Plaintiff/Appellant, vs. Da Hua Hu, and ACE INA Insurance Company Canada, Defendants/Respondents. Author: Philip M. Hess, J. Vote: REVERSED AND REMANDED. Lisa S. Van Amburg, P.J., and Patricia L. Cohen, J., concur.
EDOrder-04-08-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99897: Overview/Summary Lane House Construction, Inc., Respondent, vs. Doris Ogrowsky, Appellant. Author: Roy L. Richter, P.J. Vote: REVERSED AND REMANDED. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED99727: Overview/Summary State of Missouri, Respondent, vs. Samuel Meeks, Appellant. Author: Robert G. Dowd., Jr., J. Vote: REVERSED AND REMANDED. Lawrence E. Mooney, P.J., and Sherri B. Sullivan, J., concur.
ED99269: Overview/Summary State of Missouri, Respondent, vs. Adam L. Steinmann, Appellant. Author: Patricia L. Cohen, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J., and Philip M. Hess, J., concur.
ED100856: Overview/Summary State of Missouri, Appellant, v. Joe L. Johnson, Respondent. Author: Gary M. Gaertner, Jr., J. Vote: REVERSED. Robert M. Clayton III, C.J., and Gary Dial, S.J., concur.
ED100424: Overview/Summary Christine A. Meissner, Appellant, vs. Jeffrey Schnettgoecke, Respondent. Author: Robert M. Clayton III, C.J. Vote: REVERSED AND REMANDED. Gary M. Gaertner, Jr., J., and Gary Dial, Sp.J., concur.
EDOrder-04-01-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99940: Overview/Summary Carrie Little, Appellant, vs. State of Missouri, Respondent. Author: Roy L. Richter, P.J. Vote: AFFIRMED. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED99846: Overview/Summary Samson Desu, Plaintiff/Appellant, vs. Frederick Lewis, Defendant/Respondent. Author: Lisa S. Van Amburg, J. Vote: AFFIRMED IN PART, REVERSED IN PART AND REMANDED. Patricia L. Cohen, Judge, and Philip M. Hess, Judge, concur.
ED99841: Overview/Summary State of Missouri, Plaintiff/Respondent, v. Belvin L. Williams, Jr., Defendant/Appellant. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Robert M. Clayton III, C.J., and Angela T. Quigless, J., concur.
ED99769: Overview/Summary Ashley Janelle Lord, Respondent, vs. Directory of Revenue, State of Missouri, Appellant. Author: Kurt S. Odenwald, J. Vote: REVERSED AND REMANDED. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concur.
ED99608: Overview/Summary State of Missouri, Respondent, vs. Douglas J. Howery, Appellant. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concur.
ED99519: Overview/Summary State of Missouri, Respondent, vs. Mark G. Jackson, Appellant. Author: Robert G. Dowd, Jr., J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Sherri B. Sullivan, J., concur.
ED100014: Overview/Summary Vicki Armour-Mottaz, Claimant/Appellant, vs. Division of Employment Security, Respondent. Author: Mary K. Hoff, Judge Vote: AFFIRMED. Kurt S. Odenwald, Judge, and Angela T. Quigless, Judge, concur.
EDOrder-03-25-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99837: Overview/Summary Reliance Bank, Plaintiff/Respondent, vs. Paramont Properties, LLC, and Keith Barket, Defendants/Appellants. Author: Philip M. Hess, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J. and Patricia L. Cohen, J., concur.
ED100357: Overview/Summary Collins-Camden Partnership, L.P., Plaintiff/Appellant, v. County of Jefferson, Missouri, and Jefferson County Council Members Don Bickowski, Renee Reuter, Bob Boyer, Charles Groeteke, Terri S. Kreitler, Cliff Lane and Kelly Waymon, Defendants/Respondents. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Robert G. Dowd, Jr., J., concur.
ED100321: Overview/Summary Ardell Fields, Appellant, vs. State of Missouri, Respondent. Author: Clifford H. Ahrens, J. Vote: REVERSED AND REMANDED. Roy L. Richter, P.J., and Glenn A. Norton, J., concur.
ED100320: Overview/Summary Drury Company, Respondent/Cross-Appellant, vs. Missouri United School Insurance Counsel, Appellant, and Jackson R-2 School District, Cross-Respondent, and Warner-Nease-Bost Architects, Inc., Defendant. Author: Angela T. Quigless, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Kurt S. Odenwald, J., Concurs.
ED100308: Overview/Summary Lawrence Miller, Respondent, vs. Treasurer, State of Missouri, as Custodian of the Second Injury Fund, Appellant. Author: Clifford H. Ahrens, J. Vote: REVERSED AND VACATED. Roy L. Richter, P.J., and Glenn A. Norton, J., concur.
ED100063: Overview/Summary Todd C. Westergaard, Movant/Appellant, v. State of Missouri, Respondent/Respondent. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Robert G. Dowd, Jr., J., concur.
EDOrder-03-18-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99907: Overview/Summary State of Missouri, Respondent, vs. Nasir N. Ahmad, Appellant. Author: Roy L. Richter, P.J. Vote: DISMISSED. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED99747: Overview/Summary Greg Haddock, Appellant, vs. State of Missouri, Respondent. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concur.
ED99203: Overview/Summary Kevin Plager, Appellant, vs. Tiffany Plager, Respondent. Author: Gary M. Gaertner, Jr., J. Vote: REVERSED AND REMANDED. Robert M. Clayton III, C.J., and Karl A.W. DeMarce, S.J., concur.
ED100452: Overview/Summary Lonnie Harris, Plaintiff/Respondent, v. Bi-State Development Agency, Defendant/Appellant. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Robert G. Dowd, Jr., J., concur.
ED100191: Overview/Summary Shane Null, Respondent, vs. New Haven Care Center, Inc., Appellant, and Treasurer of Missouri as Custodian of the Second Injury Fund, Respondent. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concurs.
ED100137: Overview/Summary Tiffaney Hampton, Appellant, vs. Aerotek, Inc., and Division of Employment Security, Respondents. Author: Glenn A. Norton, J. Vote: APPEAL DISMISSED. Roy L. Richter, P.J. and Clifford H. Ahrens, J., concur.
EDOrder-03-11-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99619: Overview/Summary Jeffrey G. Thurman, Appellant, vs. State of Missouri, Respondent. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concur.
ED99517: Overview/Summary Henry Frazier, Appellant, vs. State of Missouri, Respondent. Author: Patricia L. Cohen, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J., and Gary M. Gaertner, Jr., J., concur.
ED99366: Overview/Summary State of Missouri, Respondent, v. Cemon Byrd, Appellant Author: Gary M. Gaertner, Jr., J. Vote: AFFIRMED. Robert M. Clayton III, C.J., and Karl A.W. DeMarce, S.J., concur.
ED99057: Overview/Summary Anastasia M. Hoffman, Respondent/Cross-Appellant, vs. Richard W. Hoffman, Appellant. Author: Patricia L. Cohen, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J., and Gary M. Gaertner, Jr., J., concur.
ED98906: Overview/Summary State of Missouri, Respondent, vs. George Dewey McCleary, III, Appellant. Author: Lawrence E. Mooney, P.J. Vote: JUDGMENT AFFIRMED. Robert G. Dowd, Jr., J., and Sherri B. Sullivan, J., concur.
EDOrder-03-04-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99909: Overview/Summary Arbab Adum, Respondent, vs. St. Louis Metropolitan Police Department, et al., Appellant. Author: Robert G. Dowd, Jr., J. Vote: REVERSED. Lawrence E. Mooney, P.J., concurs in result. Sherri B. Sullivan, J., concurs.
ED99852: Overview/Summary Biri M. Blevins, John T. Busey, and Charles W. Jones, Appellants, vs. American Family Mutual Insurance Company and Janey Foust, Respondents. Author: Robert M. Clayton III, C.J. Vote: REVERSED AND REMANDED IN PART AND AFFIRMED IN PART. Roy L. Richter, J., and Gary M. Gaertner, Jr., J., concur.
ED99492: Overview/Summary Tracy M. Atkinson, Respondent, v. Douglas D. Atkinson, Appellant. Author: Clifford H. Ahrens, J. Vote: REVERSED AND REMANDED. Roy L. Richter, P.J., and Glenn A. Norton, J., concur.
ED99261: Overview/Summary State of Missouri, Respondent, vs. Brenda Churchill, Appellant. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Angela T. Quigless, J., Concurs in result only and Mary K. Hoff, P.J., Dissents in separate opinion.
ED99128: Overview/Summary Richard Simmons, Appellant, vs. State of Missouri, Respondent. Author: Roy L. Richter, P.J. Vote: AFFIRMED. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED100929: Overview/Summary State of Missouri ex rel. Jason O. Salm, Relator, vs. The Honorable Chris Kunza Mennemeyer, Respondent. Author: Glenn A. Norton, J. Vote: PRELIMINARY ORDER IN MANDAMUS MADE PERMANENT. Sherri B. Sullivan, J., and Patricia L. Cohen, J., concur.
ED100276: Overview/Summary Morion S. Dawson, Appellant, v. State of Missouri, Respondent. Author: Gary M. Gaertner, Jr., J. Vote: AFFIRMED. Robert M. Clayton III, C.J., and Karl A.W. DeMarce, S.J., concur.
ED100064: Overview/Summary State of Missouri, Respondent, v. Keith Stubblefield, Appellant. Author: Gary M. Gaertner, Jr., J. Vote: AFFIRMED. Robert M. Clayton III, C.J., and Karl A.W. DeMarce, S.J., concur.
EDOrder-02-25-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99914: Overview/Summary Karl Gardner, Appellant, vs. MERS/Missouri Goodwill Industries, and Division of Employment Security, Respondents. Author: Glenn A. Norton, J. Vote: APPEAL DISMISSED. Roy L. Richter, P.J. and Clifford H. Ahrens, J., concur.
ED99869: Overview/Summary Jonathan Joyner, Appellant, vs. State of Missouri, Respondent. Author: Robert G. Dowd, Jr., J. Vote: AFFIRMED. Lawrence E. Mooney, P.J. and Sherri B. Sullivan, J., concur.
ED99868: Overview/Summary John J. Smith, Appellant, vs. Lora J. Smith, Respondent. Author: Robert G. Dowd, Jr., J. Vote: DISMISSED. Lawrence E. Mooney, P.J. and Sherri B. Sullivan, J., concur.
ED99858: Overview/Summary Danin Gray, Appellant, vs. Division of Employment Security, Respondent. Author: Robert G. Dowd, Jr., J. Vote: AFFIRMED. Lawrence E. Mooney, P.J. and Sherri B. Sullivan, J., concur.
ED99724: Overview/Summary Gavin Hauk, Respondent, vs. Scotland County Commission and It's Commissioners: Charles Harris, Jr., David Wiggins and Danette Clatt in their Official Capacities, Appellants. Author: Robert M. Clayton III, C.J. Vote: WE AFFIRM. Clifford H. Ahrens, J. and Gary M. Gaertner, Jr., J., concur.
ED99651: Overview/Summary Antonio Jackson, Appellant, vs. State of Missouri, Respondent. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concur.
ED99566: Overview/Summary A.L.C., Respondent, vs. D.A.L., Appellant. Author: Glenn A. Norton, J. Vote: REVERSED AND REMANDED. Roy L. Richter, P.J. and Clifford H. Ahrens, J., concur.
ED99440: Overview/Summary Manuel Burgess, Appellant, vs. State of Missouri, Respondent. Author: Patricia L. Cohen, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J., and Philip M. Hess, J., concur.
ED99033: Overview/Summary State of Missouri, Respondent, vs. Paul Curtis White, Appellant. Author: Robert G. Dowd, Jr., J. Vote: AFFIRMED. Lawrence E. Mooney, P.J. and Sherri B. Sullivan, J., concur.
ED98978: Overview/Summary State of Missouri, Respondent, vs. Darion Jordan Ivy, Appellant. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless J., Concur.
ED100826: Overview/Summary State of Missouri ex rel. Ernest Kizer, Relator, vs. Honorable Chris Kunza Mennemeyer, Judge of the Circuit Court of Lincoln County, Missouri, Respondent. Author: Lawrence E. Mooney, P.J. Vote: PRELIMINARY ORDER IN MANDAMUS MADE PERMANENT. Glenn A. Norton, J. and Gary M. Gaertner, Jr., J., concur.
ED100782: Overview/Summary State of Missouri ex rel. Michael Lovelace, Relator, vs. Honorable Chris Kunza Mennemeyer, Judge of the Circuit Court of Lincoln County, Missouri, Respondent. Author: Lawrence E. Mooney, P.J. Vote: PRELIMINARY ORDER IN MANDAMUS MADE PERMANENT. Glenn A. Norton, J. and Gary M. Gaertner, Jr., J., concur.
ED100153: Overview/Summary Romell Bates, Appellant, vs. State of Missouri, Respondent. Author: Robert G. Dowd, Jr., J. Vote: AFFIRMED. Lawrence E. Mooney, P.J. and Sherri B. Sullivan, J., concur.
ED100074: Overview/Summary John F. Maness, Respondent, vs. City of De Soto and Missouri Intergovernmental Risk Management Association, Appellants, and Treasurer of Missouri as Custodian of the Second Injury Fund, Respondent. Author: Angela T. Quigless, J. Vote: AFFIRMED. Mary K. Hoff, P.J. and Kurt S. Odenwald, J., Concurs.
ED99950: Overview/Summary Trudy A. Zahn, Appellant/Cross-Respondent, v. Charles W. Zahn, Respondent/Cross-Appellant. Author: Gary M. Gaertner, Jr., J. Vote: AFFIRMED IN PART AND REVERSED AND REMANDED IN PART. Lisa S. Van Amburg, P.J. and Patricia L. Cohen, J., concur.
ED99779: Overview/Summary Larry Abt, Claimant/Appellant, vs. Mississippi Lime Company, Employer/Respondent, and Treasurer of Missouri as Custodian of the Second Injury Fund, Additional Party/Respondent. Author: Lawrence E. Mooney, P.J. Vote: REVERSED AND REMANDED IN PART AND AFFIRMED IN PART. Robert G. Dowd, Jr., J., and Sherri B. Sullivan, J., concur.
ED99712: Overview/Summary State of Missouri, Respondent, vs. Leonard M. Slocum, Appellant. Author: Patricia L. Cohen, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J., and Philip M. Hess, J., concur.
ED99707: Overview/Summary John Doe, Respondent, vs. Col. Daniel Isom, et al., Appellants. Author: Roy L. Richter, P.J. Vote: REVERSED AND REMANDED. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED99427: Overview/Summary State of Missouri, Plaintiff/Respondent, vs. Claude Dale Brooks, Defendant/Appellant. Author: Lisa S. Van Amburg, J. Vote: VACATED AND REMANDED. Patricia L. Cohen, Judge, concurs. Gary M. Gaertner, Jr., Judge, dissents in separate opinion.
ED100251: Overview/Summary Stacey L. Blackshear, Claimant/Respondent, v. Adecco, Employer/Respondent, and American Home Assurance Company c/o Broadspire Services, Inc., Respondent, and Treasurer of the State of Missouri, Custodian of the Second Injury Fund, Appellant. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Robert G. Dowd, Jr., J., concur.
ED100044: Overview/Summary Thomas Binkley, Harlene J. Binkley, Roland E. Sturhahn, and Susan J. Sturhahn, Appellants, vs. American Equity Mortgage, Inc., Respondent. Author: Patricia L. Cohen, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J., and Gary M. Gaertner, Jr., J., concur.
EDOrder-02-11-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99989: Overview/Summary Bank of America, N.A., Respondent, vs. Ronald Duff d/b/a Ron Duff Video Productions and Jo Duff, Appellants. Author: Angela T. Quigless, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Kurt S. Odenwald, J., Concurs.
ED99945: Overview/Summary Cheryl Hirsch, Employee/Appellant, v. Convergys Customer Management Group, Inc., Employer/Respondent, and Division of Employment Security, Respondent/Respondent. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Robert G. Dowd, Jr., J., concur.
ED99916: Overview/Summary Christopher J. Ivory, Movant/Appellant, vs. State of Missouri, Respondent. Author: Mary K. Hoff, P.J. Vote: AFFIRMED. Kurt S. Odenwald, J., and Angela T. Quigless, J., Concur.
ED99615: Overview/Summary James Moore, Appellant, vs. State of Missouri, Respondent. Author: Roy L. Richter, P.J. Vote: DISMISSED. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED99555: Overview/Summary State of Missouri, Plaintiff/Respondent, v. Robert Baker, Defendant/Appellant. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Robert G. Dowd, Jr., J., concur.
ED99531: Overview/Summary State of Missouri, Plaintiff/Respondent, v. Chris Edward Reed, Defendant/Appellant. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Robert G. Dowd, Jr., J., concur.
ED99452: Overview/Summary Genevieve-Anne Gaudreau, Respondent, vs. Richard A. Barnes, Appellant. Author: Roy L. Richter, P.J. Vote: AFFIRMED. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED99319: Overview/Summary John T. Haidul, Appellant, vs. State of Missouri, Respondent. Author: Angela T. Quigless, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Kurt S. Odenwald, J., Concurs.
ED98875: Overview/Summary State of Missouri, Plaintiff/Respondent, vs. Christopher Sonnier, Defendant/Appellant. Author: Lisa S. Van Amburg, J. Vote: AFFIRMED. Patricia L. Cohen, J., and Philip M. Hess, J., concur.
ED98171: Overview/Summary Richard Burton and Patricia Burton, Appellants, vs. Janice Klaus, Respondent. Author: Kurt S. Odenwald, J. Vote: DISMISSED. Mary K. Hoff,P.J., and Angela T. Quigless, J., Concur.
EDOrder-02-04-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED100008: Overview/Summary Karen Hidritch-Hamann, Respondent, vs. David Hidritch and Hidritch Properties, LLC, Appellants. Author: Kurt S. Odenwald, J. Vote: DISMISSED. Mary K. Hoff,P.J., and Angela T. Quigless, J., Concur.
EDOrder-01-28-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99981: Overview/Summary KNT Management, LLC, Plaintiff/Appellant, vs. Kimberly Flenoid, Defendant/Respondent. Author: Lawrence E. Mooney, P.J. Vote: REVERSED AND REMANDED. Robert G. Dowd, Jr., J., and Sherri B. Sullivan, J., concur.
ED99787: Overview/Summary City of Moline Acres, Plaintiff/Appellant, vs. Charles W. Brennan, Defendant/Respondent. Author: Lisa S. Van Amburg, P.J. Vote: AFFIRMED. Patricia L. Cohen, J. and Philip M. Hess, J., concur.
ED99499: Overview/Summary In the Matter of: T.S.D. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concur.
ED99088: Overview/Summary State of Missouri, Respondent, vs. Christopher Eric Hunt, Appellant. Author: Robert G. Dowd, Jr., J. Vote: AFFIRMED IN PART AND REVERSED AND REMANDED IN PART. Lawrence E. Mooney, P.J. and Sherri B. Sullivan, J., concur.
ED98277: Overview/Summary State of Missouri, Respondent, vs. George Turner, Appellant. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless J., Concur.
ED100045: Overview/Summary Rochelle Hardin, Appellant, vs. Adecco USA, Inc., Defendant/Respondent, and Biomerieux, Inc., Defendant, and Tony Dansberry, Defendant. Author: Lawrence E. Mooney, P.J. Vote: APPEAL DISMISSED. Robert G. Dowd, Jr., J., and Sherri B. Sullivan, J., concur.
ED99832: Overview/Summary State of Missouri ex rel. Arnie C. Dienoff, Respondent, vs. Patricia Galkowski, St. Charles County Ambulance District, Appellants, and Rich A. Chrismer and St. Charles County, Missouri, Defendants. Author: PER CURIAM. Vote: REVERSED AND REMANDED. Lisa S. Van Amburg, P.J., Patricia L. Cohen, J., and Gary M. Gaertner, Jr., J.
EDOrder-01-21-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99632: Overview/Summary Charles Kyles, Appellant, vs. State of Missouri, Respondent. Author: Patricia L. Cohen, J. Vote: REVERSED AND REMANDED. Lisa S. Van Amburg, P.J., and Philip M. Hess, J., concur.
ED99569: Overview/Summary Phillip R. Sullins, Appellant, vs. Snow C. Sullins, Respondent. Author: Roy L. Richter, P.J. Vote: AFFIRM IN PART; REVERSE AND REMAND IN PART. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED99553: Overview/Summary Dr. John B. Weltmer, Jr., Appellant, vs. Signature Health Services Inc. f/k/a Premier Care, Inc., St. Louis County Orthopedic Group Inc., SLCOG Property Management & Leasing Company, LLC, and Premier Care Leasing, LLC, Respondents. Author: Gary M. Gaertner, Jr., J. Vote: REVERSED IN PART AND AFFIRMED IN PART. Lisa S. Van Amburg, P.J. and Patricia L. Cohen, J., concur.
EDOrder-01-14-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99135: Overview/Summary State of Missouri, Respondent, vs. Willie Davis, Appellant. Author: Robert M. Clayton III, C.J. Vote: AFFIRMED IN PART AND REVERSED AND REMANDED IN PART. Glenn A. Norton, J. and Patricia L. Cohen, J., concur.
EDOrder-01-07-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)